@@ -1,11 +1,11 @@
 // Copyright (C) 2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com, author Milian Wolff <milian.wolff@kdab.com>
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include <QtQuickTest/quicktest.h>
 #include <QtQml/qqml.h>
 
 #ifndef QUICK_TEST_SOURCE_DIR
-#define QUICK_TEST_SOURCE_DIR Q_NULLPTR
+#define QUICK_TEST_SOURCE_DIR nullptr
 #endif
 
 #include "testtransport.h"
